import os
import requests

import pandas as pd


class Datasets(object):
    @staticmethod
    def load_data(key):
        """
        Return path for available datasets.
        """

        _datasets = {
            "chi_times": "chicago_metro_times.csv.bz2",
            "chi_doc": "chicago_metro_docs_dentists.csv",
            "chi_pop": "chicago_metro_pop.csv",
            "chi_doc_geom": "chicago_metro_docs_dentists.geojson",
            "chi_pop_geom": "chicago_metro_pop.geojson",
            "chi_euclidean": "chicago_metro_euclidean_costs.csv.bz2",
            "chi_euclidean_neighbors": "chicago_metro_euclidean_cost_neighbors.csv.bz2",
            "cook_county_hospitals": "cook_county_hospitals.csv",
            "cook_county_hospitals_geom": "hospitals_cookcty.geojson",
            "cook_county_tracts": "cook_county_tracts.geojson",
        }

        url = f"https://uchicago-csds-access.s3.amazonaws.com/ex_datasets/{_datasets[key]}"

        if ".geojson" in url:
            import geopandas as gpd

            return gpd.read_file(url)

        return pd.read_csv(url)

    @staticmethod
    def available_datasets():
        desc = """
chi_times: Cost matrix with travel times from each Chicago Census Tract to all others.\n
chi_doc: Doctor and dentist counts for each Chicago Census Tract.\n
chi_pop: Population counts for each Chicago Census Tract.\n
chi_doc_geom: Doctor and dentist counts for each Chicago Census Tract along with geometric representations for Census Tracts.\n
chi_pop_geom: Population counts for each Chicago Census Tract along with geometric representations for Census Tracts.\n
chi_euclidean: Euclidean distance cost matrix with distances from each demand Chicago Census Tract to all others.\n
chi_euclidean_neighbors: Euclidean distance cost matrix with distances from each supply Census Tract to all others.\n
cook_county_hospitals: Contains data for each hospital location in Cook County including X Y coordinates.\n
cook_county_hospitals_geom: Contains data for each hospital location in Cook County including X Y coordinates, and geometric points for each hospital.\n
cook_county_tracts: Geometric representation of each Census Tract in Cook County.
        """
        print(desc)



from setuptools import setup, find_packages
from distutils.command.build_py import build_py

# Get __version__ from access/__init__.py without importing the package
# __version__ has to be defined in the first line
with open("access/__init__.py", "r") as f:
    exec(f.readline())

with open("README.md", "r") as fh:
    long_description = fh.read()


def _get_requirements_from_files(groups_files):
    groups_reqlist = {}

    for k, v in groups_files.items():
        with open(v, "r") as f:
            pkg_list = f.read().splitlines()
        groups_reqlist[k] = pkg_list

    return groups_reqlist


def setup_package():

    _groups_files = {
        "base": "requirements.txt",  # basic requirements
        "tests": "requirements_tests.txt",  # requirements for tests
        "docs": "requirements_docs.txt",  # requirements for building docs
    }
    reqs = _get_requirements_from_files(_groups_files)
    install_reqs = reqs.pop("base")
    extras_reqs = reqs

    setup(
        name="access",  # name of package
        version=__version__,
        description="Calculate spatial accessibility metrics.",  # short <80chr description
        long_description=long_description,
        long_description_content_type="text/markdown",
        url="https://access.readthedocs.io/en/latest/",  # github repo
        maintainer="James Saxon",
        maintainer_email="jsaxon@uchicago.edu",
        keywords="spatial statistics access",
        classifiers=[
            "Development Status :: 5 - Production/Stable",
            "Intended Audience :: Science/Research",
            "Intended Audience :: Developers",
            "Intended Audience :: Education",
            "Topic :: Scientific/Engineering",
            "Topic :: Scientific/Engineering :: GIS",
            "License :: OSI Approved :: BSD License",
            "Programming Language :: Python",
            "Programming Language :: Python :: 3.7",
            "Programming Language :: Python :: 3.8",
            "Programming Language :: Python :: 3.9",
            "Programming Language :: Python :: 3.10",
        ],
        license="3-Clause BSD",
        packages=find_packages(),
        install_requires=install_reqs,
        extras_require=extras_reqs,
        zip_safe=False,
        cmdclass={"build.py": build_py},
    )


if __name__ == "__main__":

    setup_package()
